@@ -230,18 +230,18 @@ static int pngrw_read_png(struct pngrw_ctx *ctx, FILE *infp, int verbose)
 	    (void*)(&errinfo),my_png_error_fn, my_png_warning_fn);
 
 	if(!png_ptr) {
-		pngrw_print_error(ctx,PNGRW_TEXT("Error creating read_struct"));
+		pngrw_print_error(ctx,PNGRW_TEXT("pngrecolor error: Error creating read_struct"));
 		goto done;
 	}
 
 	info_ptr = png_create_info_struct(png_ptr);
 	if(!info_ptr) {
-		pngrw_print_error(ctx,PNGRW_TEXT("Error creating read_info_struct"));
+		pngrw_print_error(ctx,PNGRW_TEXT("pngrecolor error: Error creating read_info_struct"));
 		goto done;
 	}
 
 	if (setjmp(errinfo.jbuf)) {
-		pngrw_print_error(ctx,PNGRW_TEXT("PNG decode error: %s"), errinfo.errmsg);
+		pngrw_print_error(ctx,PNGRW_TEXT("pngrecolor error: PNG decode error: %s"), errinfo.errmsg);
 		goto done;
 	}
 
@@ -254,7 +254,7 @@ static int pngrw_read_png(struct pngrw_ctx *ctx, FILE *infp, int verbose)
 
 	if(ctx->bit_depth>8) {
 		// TODO: Some (rare?) 16-bpp images *can* be perfectly converted to palette images.
-		pngrw_print_error(ctx,PNGRW_TEXT("This image can't be converted because it has 16 bits/sample."));
+		pngrw_print_error(ctx,PNGRW_TEXT("pngrecolor warning: This image can't be converted because it has 16 bits/sample."));
 		goto done;
 	}
 
@@ -307,12 +307,12 @@ static int pngrw_read_png(struct pngrw_ctx *ctx, FILE *infp, int verbose)
 	ctx->channels=(int)png_get_channels(png_ptr, info_ptr);
 
 	if(ctx->channels<3 || ctx->channels>4) {
-		pngrw_print_error(ctx,PNGRW_TEXT("internal error: channels=%d"),ctx->channels);
+		pngrw_print_error(ctx,PNGRW_TEXT("pngrecolor error: internal error: channels=%d"),ctx->channels);
 		goto done;
 	}
 
 	if (verbose) {
-		pngrw_print_info(ctx,PNGRW_TEXT("Image size is %dx%d  memory required=%.3fMB"),
+		pngrw_print_info(ctx,PNGRW_TEXT("pngrecolor message: Image size is %dx%d  memory required=%.3fMB"),
 			(int)ctx->width, (int)ctx->height,
 			(ctx->height*ctx->rowbytes + ctx->height*sizeof(unsigned char*) + ctx->width*ctx->height) / (1024. * 1024.) );
 	}
@@ -320,7 +320,7 @@ static int pngrw_read_png(struct pngrw_ctx *ctx, FILE *infp, int verbose)
 	ctx->image1= (unsigned char*)malloc(ctx->height*ctx->rowbytes);
 	ctx->row_pointers1 = (unsigned char**)malloc(ctx->height * sizeof(unsigned char*));
 	if(!ctx->image1 || !ctx->row_pointers1) {
-		pngrw_print_error(ctx,PNGRW_TEXT("Unable to allocate memory for image"));
+		pngrw_print_error(ctx,PNGRW_TEXT("pngrecolor error: Unable to allocate memory for image"));
 		goto done;
 	}
 
@@ -378,18 +378,18 @@ static int pngrw_write_new_png(struct pngrw_ctx *ctx, FILE *outfp, int no_interl
     png_ptr = png_create_write_struct(PNG_LIBPNG_VER_STRING,
 		(void*)(&errinfo),my_png_error_fn, my_png_warning_fn);
 	if (!png_ptr) {
-		pngrw_print_error(ctx,PNGRW_TEXT("Error creating write_struct"));
+		pngrw_print_error(ctx,PNGRW_TEXT("pngrecolor error: Error creating write_struct"));
 		goto done;
 	}
 
     info_ptr = png_create_info_struct(png_ptr);
     if (!info_ptr) {
-		pngrw_print_error(ctx,PNGRW_TEXT("Error creating write_info_struct"));
+		pngrw_print_error(ctx,PNGRW_TEXT("pngrecolor error: Error creating write_info_struct"));
         goto done;
     }
 
 	if (setjmp(errinfo.jbuf)) {
-		pngrw_print_error(ctx,PNGRW_TEXT("PNG encode error: %s"), errinfo.errmsg);
+		pngrw_print_error(ctx,PNGRW_TEXT("pngrecolor error: PNG encode error: %s"), errinfo.errmsg);
 		goto done;
 	}
 
@@ -471,7 +471,7 @@ add_to_palette(struct pngrw_ctx *ctx, const struct pal_entry_info *color, int ig
 {
 	if(ctx->pal_used>=256) {
 		if (verbose) {
-			pngrw_print_error(ctx,PNGRW_TEXT("This image can't be converted because it has more than 256 colors."));
+			pngrw_print_error(ctx,PNGRW_TEXT("pngrecolor warning: This image can't be converted because it has more than 256 colors."));
 		}
 		return 0;
 	}
@@ -715,7 +715,7 @@ static int pngrw_create_grayscale_palette(struct pngrw_ctx *ctx)
 	if(ctx->gray_trns_orig_palentry != -1) {
 		ctx->gray_trns_target_palentry=find_pal_entry(ctx,ctx->gray_trns_shade,ctx->gray_trns_shade,ctx->gray_trns_shade,255,PNGRW_ALPHA_MUST_MATCH);
 		if(ctx->gray_trns_target_palentry == -1) {
-			pngrw_print_error(ctx,PNGRW_TEXT("internal error: can't find transparent grayscale color"));
+			pngrw_print_error(ctx,PNGRW_TEXT("pngrecolor error: internal error: can't find transparent grayscale color"));
 			return 0;
 		}
 		ctx->pal[ctx->gray_trns_target_palentry].alpha = 0;
@@ -735,7 +735,7 @@ static int pngrw_generate_optimized_image(struct pngrw_ctx *ctx)
 	ctx->image2 = (unsigned char*)malloc(ctx->width*ctx->height);
 	ctx->row_pointers2 = (unsigned char**)malloc(ctx->height * sizeof(unsigned char*));
 	if(!ctx->image2 || !ctx->row_pointers2) {
-		pngrw_print_error(ctx,PNGRW_TEXT("out of memory"));
+		pngrw_print_error(ctx,PNGRW_TEXT("pngrecolor error: out of memory"));
 		return 0;
 	}
 
@@ -749,7 +749,7 @@ static int pngrw_generate_optimized_image(struct pngrw_ctx *ctx)
 
 			palent = find_pal_entry(ctx,p[0],p[1],p[2],(unsigned char)((ctx->channels==4)?p[3]:255),PNGRW_ALPHA_MUST_MATCH);
 			if(palent<0) {
-				pngrw_print_error(ctx,PNGRW_TEXT("internal error: can't locate palette entry"));
+				pngrw_print_error(ctx,PNGRW_TEXT("pngrecolor error: internal error: can't locate palette entry"));
 				return 0;
 			}
 			ctx->row_pointers2[y][x] = (unsigned char)palent;
@@ -759,7 +759,7 @@ static int pngrw_generate_optimized_image(struct pngrw_ctx *ctx)
 	if(ctx->has_bKGD) {
 		palent = find_pal_entry_p(ctx,&ctx->bkgd,PNGRW_IGNORE_ALPHA);
 		if(palent<0) {
-			pngrw_print_error(ctx,PNGRW_TEXT("internal error: can't locate palette entry for bkgd"));
+			pngrw_print_error(ctx,PNGRW_TEXT("pngrecolor error: internal error: can't locate palette entry for bkgd"));
 			return 0;
 		}
 		ctx->bkgd_pal = (unsigned char)palent;
@@ -863,7 +863,7 @@ int pngrw_read_filename(struct pngrw_ctx *ctx, const PNGRW_CHAR *in_filename, in
 
 	infp = _tfopen(in_filename, PNGRW_TEXT("rb"));
 	if(!infp) {
-		pngrw_print_error(ctx,PNGRW_TEXT("Failed to open file for reading"));
+		pngrw_print_error(ctx,PNGRW_TEXT("pngrecolor error: Failed to open file for reading"));
 		return 0;
 	}
 
@@ -879,7 +879,7 @@ int pngrw_write_filename(struct pngrw_ctx *ctx, const PNGRW_CHAR *out_filename,
 
 	outfp = _tfopen(out_filename, PNGRW_TEXT("wb"));
 	if(!outfp) {
-		pngrw_print_error(ctx,PNGRW_TEXT("Failed to open file for writing"));
+		pngrw_print_error(ctx,PNGRW_TEXT("pngrecolor error: Failed to open file for writing"));
 		return 0;
 	}
 
