@@ -16,28 +16,37 @@
    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <https://www.gnu.org/licenses/>.  */
 
-/* Written by David Madore, considerably copypasting from
-   Scott G. Miller's sha1.c.  Modifications for partial file
-   reads by Brian Lindholm, 2007-2013.
-*/
+/* Written by David Madore, considerably copypasting from Scott G. Miller's
+   sha1.c.  Modifications for portability and partial file reads by Brian
+   Lindholm, 2007-2018.  */
 
 #include "../config.h"
-#include <sys/types.h>
+#ifdef HAVE_SYS_TYPES_H
+# include <sys/types.h>
+#endif
 #include "sha256.h"
-#include <stdalign.h>
-#include <stdint.h>
-#include <stdlib.h>
+#ifdef HAVE_STDALIGN_H
+# include <stdalign.h>
+#endif
+#ifdef HAVE_STDINT_H
+# include <stdint.h>
+#endif
+#ifdef HAVE_STDLIB_H
+# include <stdlib.h>
+#endif
 #include <string.h>
-
-#if USE_UNLOCKED_IO
-# include "unlocked-io.h"
+# ifdef HAVE_STRING_H
 #endif
 
-#include <byteswap.h>
 #ifdef WORDS_BIGENDIAN
 # define SWAP(n) (n)
 #else
-# define SWAP(n) bswap_32 (n)
+# ifdef HAVE_BYTESWAP_H
+#  include <byteswap.h>
+#  define SWAP(n) bswap_32 (n)
+# else
+#  define SWAP(n) (((n) << 24) | (((n) & 0xff00) << 8) | (((n) >> 8) & 0xff00) | ((n) >> 24))
+# endif
 #endif
 
 #define BLOCKSIZE 32768
